"use client"

import { useState, useRef } from 'react';
import { postRegData } from '@/lib/postRegData';

const SignUpForm = () => {
  const [successMessage, setSuccessMessage] = useState('');
  const [afterdata, setAfterdata] = useState(null);
  const idRef = useRef();
  const emailRef = useRef();
  const passwordRef = useRef();
  const repeatPasswordRef = useRef();

  const handleSubmit = async (e) => {
    e.preventDefault();
     const confirmed = window.confirm('Are you sure you want to submit the form?');

    if (!confirmed) {
      return;
    }
    const formData = {
      id: idRef.current.value,
      email: emailRef.current.value,
      password: passwordRef.current.value
    };
    try {
      const response = postRegData(formData);

      if (!response) {
        throw new Error('Failed to submit form data');
      }
      // Clear the form fields
      idRef.current.value = '';
      emailRef.current.value = '';
      passwordRef.current.value = '';
      repeatPasswordRef.current.value = '';

      // Set success message
      alert('Data saved successfully');
      setSuccessMessage('Data saved successfully');

      // Hide success message after 3 seconds
      setTimeout(() => {
        setSuccessMessage('');
      }, 3000);
      // Handle success response
      console.log('Form data submitted successfully');
    } catch (error) {
      console.error('Error submitting form data:', error.message);
    }
  };

  return (
    <>
    <form onSubmit={handleSubmit} className="max-w-md mx-auto mt-8 p-6 border border-indigo-600">
      <div className="mb-4">
        <label htmlFor="id" className="block mb-2">ID</label>
        <input
          type="text"
          id="id"
          ref={idRef}
          className="w-full border border-gray-300 rounded-md px-3 py-2"
          required
        />
      </div>
      <div className="mb-4">
        <label htmlFor="email" className="block mb-2">Email</label>
        <input
          type="email"
          id="email"
          ref={emailRef}
          className="w-full border border-gray-300 rounded-md px-3 py-2"
          required
        />
      </div>
      <div className="mb-4">
        <label htmlFor="password" className="block mb-2">Password</label>
        <input
          type="password"
          id="password"
          ref={passwordRef}
          className="w-full border border-gray-300 rounded-md px-3 py-2"
          required
        />
      </div>
      <div className="mb-4">
        <label htmlFor="repeatPassword" className="block mb-2">Repeat Password</label>
        <input
          type="password"
          id="repeatPassword"
          ref={repeatPasswordRef}
          className="w-full border border-gray-300 rounded-md px-3 py-2"
          required
        />
      </div>
      <button type="submit" className="bg-blue-500 text-white py-2 px-4 rounded-md hover:bg-blue-600">
        Submit
      </button>
      {successMessage && (
        <p className="mt-4 text-green-600">{successMessage}</p>
      )}
    </form>
    </>
  );
};

export default SignUpForm;

